Documentation
¶
Index ¶
- Constants
- type Logger
- func (l *Logger) Debug(message string)
- func (l *Logger) Debugf(message string, a ...interface{})
- func (l *Logger) Error(message string)
- func (l *Logger) Errorf(message string, a ...interface{})
- func (l *Logger) Info(message string)
- func (l *Logger) Infof(message string, a ...interface{})
- func (l *Logger) Warning(message string)
- func (l *Logger) Warningf(message string, a ...interface{})
Constants ¶
const ( STDOUT = 1 << iota STDERR FILE )
Constant that define where the logger will be writing
const DateTimeFormat = "02-01-2006 15:04:05"
DateTimeFormat defines the custom date and time format for logs
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger is the logging object
func GetLogger ¶
GetLogger is a function that creates a new logger If name is not provided, it uses the caller function name
func (*Logger) Debugf ¶ added in v0.3.0
Debugf register a log message with string interpolation and Debug level
Click to show internal directories.
Click to hide internal directories.