Documentation
¶
Index ¶
Constants ¶
const ( STDOUT = 1 << iota STDERR FILE )
Constant that define where the logger will be writing
const DateTimeFormat = "02-01-2006 15:04:05"
DateTimeFormat defines the custom date and time format for logs
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger is the logging object
Click to show internal directories.
Click to hide internal directories.